==> sartoric-modular-cms-1.1.1-361347.zip: src/Views/errors/503.blade.php <==

<!DOCTYPE html>

{{--[if IE 8]> <html lang="en" class="ie8 no-js"> <![endif]--}}
{{--[if IE 9]> <html lang="en" class="ie9 no-js"> <![endif]--}}
{{--[if !IE]>{{--}}
<html lang="{{ app()->getLocale() }}">
{{--<![endif]--}}
{{-- BEGIN HEAD --}}

<head>
    <meta charset="utf-8" />
    <title>{{ config('app.name', 'Laravel') }}</title>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta content="width=device-width, initial-scale=1" name="viewport" />
    <meta content="" name="author" />
    {{-- BEGIN GLOBAL MANDATORY STYLES --}}
    {{--Material Icon--}}
    <link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet" >
    {{--Font--}}
    <link href="http://fonts.googleapis.com/css?family=Open+Sans:400,300,600,700&subset=all" rel="stylesheet" type="text/css" />
    <link href="http://fonts.googleapis.com/css?family=Roboto:300,400,500,700,400" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/font-awesome/css/font-awesome.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/simple-line-icons/simple-line-icons.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/bootstrap/css/bootstrap.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/bootstrap-switch/css/bootstrap-switch.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END GLOBAL MANDATORY STYLES --}}
    {{-- BEGIN PAGE LEVEL PLUGINS --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/pages/css/error.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END PAGE LEVEL PLUGINS --}}
    {{-- BEGIN THEME GLOBAL STYLES --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/global/css/components-md.min.css') }}" rel="stylesheet" id="style_components" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/css/plugins-md.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END THEME GLOBAL STYLES --}}
    {{-- BEGIN THEME LAYOUT STYLES --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/layout.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/themes/light.min.css') }}" rel="stylesheet" type="text/css" id="style_color" />
    {{--CUSTOM CSS (SCSS)--}}
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/custom.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END THEME LAYOUT STYLES --}}
    <link rel="shortcut icon" href="favicon.ico" /> </head>
{{-- END HEAD --}}


<body class="page-500-full-page">
<style>
    .page-500-full-page{
        background-color: #364150 !important;
    }
</style>

<div class="row">
    <div class="col-md-12 page-500">
        <div class="number">
            <img src="{{ McmsHelper::mcmsAsset('assets/pages/images/logo-big.png')}} " alt="logo" class="logo-default" />
        </div>
        <div class="details font-grey">
            <h1>{{ __('Sito in manutenzione') }}</h1>
           <p> {{ __('Il sito non è momentaneamente disponibile, riprovate più tardi') }}</p>
        </div>
    </div>
</div>


{{-- BEGIN CORE PLUGINS --}}

{{-- END THEME LAYOUT SCRIPTS --}}
</body>

</html>

==> sartoric-modular-cms-1.1.9-5a7a15.zip: src/Views/errors/503.blade.php <==

<!DOCTYPE html>

{{--[if IE 8]> <html lang="en" class="ie8 no-js"> <![endif]--}}
{{--[if IE 9]> <html lang="en" class="ie9 no-js"> <![endif]--}}
{{--[if !IE]>{{--}}
<html lang="{{ app()->getLocale() }}">
{{--<![endif]--}}
{{-- BEGIN HEAD --}}

<head>
    <meta charset="utf-8" />
    <title>{{ config('app.name', 'Laravel') }}</title>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta content="width=device-width, initial-scale=1" name="viewport" />
    <meta content="" name="author" />
    {{-- BEGIN GLOBAL MANDATORY STYLES --}}
    {{--Material Icon--}}
    <link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet" >
    {{--Font--}}
    <link href="http://fonts.googleapis.com/css?family=Open+Sans:400,300,600,700&subset=all" rel="stylesheet" type="text/css" />
    <link href="http://fonts.googleapis.com/css?family=Roboto:300,400,500,700,400" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/font-awesome/css/font-awesome.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/simple-line-icons/simple-line-icons.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/bootstrap/css/bootstrap.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/plugins/bootstrap-switch/css/bootstrap-switch.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END GLOBAL MANDATORY STYLES --}}
    {{-- BEGIN PAGE LEVEL PLUGINS --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/pages/css/error.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END PAGE LEVEL PLUGINS --}}
    {{-- BEGIN THEME GLOBAL STYLES --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/global/css/components-md.min.css') }}" rel="stylesheet" id="style_components" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/global/css/plugins-md.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END THEME GLOBAL STYLES --}}
    {{-- BEGIN THEME LAYOUT STYLES --}}
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/layout.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/themes/light.min.css') }}" rel="stylesheet" type="text/css" id="style_color" />
    {{--CUSTOM CSS (SCSS)--}}
    <link href="{{ McmsHelper::mcmsAsset('assets/layouts/layout/css/custom.min.css') }}" rel="stylesheet" type="text/css" />
    {{-- END THEME LAYOUT STYLES --}}
    <link rel="shortcut icon" href={{ McmsHelper::mcmsAsset("assets/pages/images/favicon.ico") }} />
</head>
{{-- END HEAD --}}


<body class="page-500-full-page">
<style>
    .page-500-full-page{
        background-color: #364150 !important;
    }
</style>

<div class="row">
    <div class="col-md-12 page-500">
        <div class="number">
            <img src="{{ McmsHelper::mcmsAsset('assets/pages/images/logo-big.png')}} " alt="logo" class="logo-default" />
        </div>
        <div class="details font-grey">
            <h1>{{ __('Sito in manutenzione') }}</h1>
           <p> {{ __('Il sito non è momentaneamente disponibile, riprovate più tardi') }}</p>
        </div>
    </div>
</div>


{{-- BEGIN CORE PLUGINS --}}

{{-- END THEME LAYOUT SCRIPTS --}}
</body>

</html>
